@@ -214,6 +214,46 @@ X502_EXPORT(int32_t) E502_UsbGetDevRecordsList(t_x502_devrec* list, uint32_t siz
 X502_EXPORT(int32_t) E502_MakeDevRecordByIpAddr(t_x502_devrec *devrec, uint32_t ip_addr,
                                                 uint32_t flags, uint32_t tout);
 
+
+/***************************************************************************//**
+    @brief Установка TCP-порта управляющего соединения для записи о устройстве
+
+    Данная функция позволяет изменить TCP-порт управляющего соединения модуля
+    E502. Это может быть необходимо, если модуль E502  и хост, с которого
+    необходимо установить соединение, находятся в разных сетях и адрес модуля
+    E502 не доступен из сети хоста. В этом случае требуется настройка проброса
+    портов на маршрутизаторе и при наличие более одного такого модуля E502, т.к.
+    все соединения идут с маршрутизитором, то различить эти модули можно только
+    по TCP-порту, если настроить разные порты при пробросе.
+    В этом случае помимо порта управляющего соединения, необходимо изменить и
+    порт соединения для передачи данных, вызвав E502_EthDevRecordSetDataPort().
+
+    Данная функция должна быть вызвана для записи, созданной до этого с помощью
+    E502_MakeDevRecordByIpAddr() и до открытия соединения с помощью
+    X502_OpenByDevRecord().
+
+    @param[in] devrec   Указатель на запись устройства, в которой нужно изменить
+                         управляющий TCP-порт.
+    @param[in] cmd_port Новое значение TCP-порта для управляющего соединения
+    @return             Код ошибки
+*******************************************************************************/
+X502_EXPORT(int32_t) E502_EthDevRecordSetCmdPort(t_x502_devrec *devrec, uint16_t cmd_port);
+
+/***************************************************************************//**
+    @brief Установка TCP-порта соединения передачи данных для записи о устройстве
+
+    Функция аналогична E502_EthDevRecordSetCmdPort(), но изменяет TCP-порт для
+    соединения, по которому идет обмен данных потоков ввода-вывода.
+
+    @param[in] devrec   Указатель на запись устройства, в которой нужно изменить
+                         управляющий TCP-порт.
+    @param[in] data_port Новое значение TCP-порта для соединения передачи данных
+    @return             Код ошибки
+*******************************************************************************/
+X502_EXPORT(int32_t) E502_EthDevRecordSetDataPort(t_x502_devrec *devrec, uint16_t data_port);
+
+
+
 /***************************************************************************//**
     @brief Создание записи о устройстве по описателю сетевого сервиса
 
